# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame.status
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Verb(object):
    """
    Struct Class

    describes a command that can be send to an OLE object
    
    For example, this can be used to select a font.
    
    **since**
    
        OOo 2.0

    See Also:
        `API Verb <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1status_1_1Verb.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame.status'
    __ooo_full_ns__: str = 'com.sun.star.frame.status.Verb'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.frame.status.Verb'
    """Literal Constant ``com.sun.star.frame.status.Verb``"""

    def __init__(self, VerbId: typing.Optional[int] = 0, VerbName: typing.Optional[str] = '', VerbIsOnMenu: typing.Optional[bool] = False, VerbIsConst: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            VerbId (int, optional): VerbId value.
            VerbName (str, optional): VerbName value.
            VerbIsOnMenu (bool, optional): VerbIsOnMenu value.
            VerbIsConst (bool, optional): VerbIsConst value.
        """
        super().__init__()

        if isinstance(VerbId, Verb):
            oth: Verb = VerbId
            self.VerbId = oth.VerbId
            self.VerbName = oth.VerbName
            self.VerbIsOnMenu = oth.VerbIsOnMenu
            self.VerbIsConst = oth.VerbIsConst
            return

        kargs = {
            "VerbId": VerbId,
            "VerbName": VerbName,
            "VerbIsOnMenu": VerbIsOnMenu,
            "VerbIsConst": VerbIsConst,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._verb_id = kwargs["VerbId"]
        self._verb_name = kwargs["VerbName"]
        self._verb_is_on_menu = kwargs["VerbIsOnMenu"]
        self._verb_is_const = kwargs["VerbIsConst"]


    @property
    def VerbId(self) -> int:
        """
        specifies the Id of the command.
        """
        return self._verb_id

    @VerbId.setter
    def VerbId(self, value: int) -> None:
        self._verb_id = value

    @property
    def VerbName(self) -> str:
        """
        specifies the name of the command.
        
        The name is localized.
        """
        return self._verb_name

    @VerbName.setter
    def VerbName(self, value: str) -> None:
        self._verb_name = value

    @property
    def VerbIsOnMenu(self) -> bool:
        """
        specifies if the command should be visible in a menu.
        """
        return self._verb_is_on_menu

    @VerbIsOnMenu.setter
    def VerbIsOnMenu(self, value: bool) -> None:
        self._verb_is_on_menu = value

    @property
    def VerbIsConst(self) -> bool:
        """
        specifies if the command is available for a constant object.
        """
        return self._verb_is_const

    @VerbIsConst.setter
    def VerbIsConst(self, value: bool) -> None:
        self._verb_is_const = value


__all__ = ['Verb']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47

class XStarBasicAccess(XInterface_8f010a43):
    """
    Interface representing a library and provides access to its modules.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XStarBasicAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1XStarBasicAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.XStarBasicAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.XStarBasicAccess'

    @abstractmethod
    def addDialog(self, LibraryName: str, DialogName: str, Data: uno.ByteSequence) -> None:
        """
        Adds an old style basic dialog (SI controls) to an existing (e.g., created by createLibrary) library.
        
        By using this method together with createLibrary the caller does not have to implement XStarBasicLibraryInfo and XStarBasicDialogInfo

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def addModule(self, LibraryName: str, ModuleName: str, Language: str, Source: str) -> None:
        """
        Adds a module to an existing (e.g., created by createLibrary) library.
        
        By using this method together with createLibrary the caller does not have to implement XStarBasicLibraryInfo and XModuleInfo.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def createLibrary(self, LibName: str, Password: str, ExternalSourceURL: str, LinkTargetURL: str) -> None:
        """
        Creates an empty library.
        
        This method can be called alternatively to accessing directly the NameContainer returned by getLibraryContainer. By using this method together with addModule and addStarBasicDialog the caller does not have to implement XStarBasicLibraryInfo, XModuleInfo, and XStarBasicDialogInfo

        Raises:
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def getLibraryContainer(self) -> XNameContainer_cb90e47:
        """
        returns the library container giving access to the libraries stored in a document or basic library file.
        """
        ...

__all__ = ['XStarBasicAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class FormSubmitEncoding(metaclass=UnoEnumMeta, type_name="com.sun.star.form.FormSubmitEncoding", name_space="com.sun.star.form"):
        """Dynamically created class that represents ``com.sun.star.form.FormSubmitEncoding`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.form.FormSubmitEncoding import MULTIPART as FORM_SUBMIT_ENCODING_MULTIPART
        from com.sun.star.form.FormSubmitEncoding import TEXT as FORM_SUBMIT_ENCODING_TEXT
        from com.sun.star.form.FormSubmitEncoding import URL as FORM_SUBMIT_ENCODING_URL

        class FormSubmitEncoding(uno.Enum):
            """
            Enum Class


            See Also:
                `API FormSubmitEncoding <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form.html#a4a4c5c07c0618f59711919741a523ab8>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.form.FormSubmitEncoding', value)

            __ooo_ns__: str = 'com.sun.star.form'
            __ooo_full_ns__: str = 'com.sun.star.form.FormSubmitEncoding'
            __ooo_type_name__: str = 'enum'

            MULTIPART = FORM_SUBMIT_ENCODING_MULTIPART
            """
            Specifies to use \"multipart/form-data\" as submit encoding.

            Usually used when the form contains a file upload element.
            """
            TEXT = FORM_SUBMIT_ENCODING_TEXT
            """
            specifies to use \"text/plain\"

            Usually used if the FormSubmitMethod attribute has the value POST and the content should be reviewed as full text.
            """
            URL = FORM_SUBMIT_ENCODING_URL
            """
            When the button is clicked, a URL set for the button is opened.

            Specifies to use \"application/x-www-form-urlencoded\" as submit encoding.

            Usually used if the FormSubmitMethod attribute has the value POST.
            """
    else:
        # keep document generators happy
        from ...lo.form.form_submit_encoding import FormSubmitEncoding as FormSubmitEncoding


__all__ = ['FormSubmitEncoding']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.beans
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class Optional(object):
    """
    Struct Class

    An optional value of a given type.
    
    This structure is used as the type of interface attributes corresponding to instances of com.sun.star.beans.Property that have the com.sun.star.beans.PropertyAttribute.MAYBEVOID. It might also be useful in other situations, for example as the return type of an interface method.

    See Also:
        `API Optional <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1beans_1_1Optional_3_01T_01_4.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.beans'
    __ooo_full_ns__: str = 'com.sun.star.beans.Optional'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.beans.Optional'
    """Literal Constant ``com.sun.star.beans.Optional``"""

    def __init__(self, IsPresent: typing.Optional[bool] = None, Value: typing.Optional[object] = None) -> None:
        """
        Constructor

        Arguments:
            IsPresent (bool, optional): IsPresent value.
            Value (object, optional): Value value.
        """
        super().__init__()

        if isinstance(IsPresent, Optional):
            oth: Optional = IsPresent
            self.IsPresent = oth.IsPresent
            self.Value = oth.Value
            return

        kargs = {
            "IsPresent": IsPresent,
            "Value": Value,
        }
        if kargs["IsPresent"] is UNO_NONE:
            kargs["IsPresent"] = None
        if kargs["Value"] is UNO_NONE:
            kargs["Value"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._is_present = kwargs["IsPresent"]
        self._value = kwargs["Value"]


    @property
    def IsPresent(self) -> bool:
        """
        Marks this structure instance as having an actual value.
        """
        return self._is_present

    @IsPresent.setter
    def IsPresent(self, value: bool) -> None:
        self._is_present = value

    @property
    def Value(self) -> object:
        """
        The actual value of this structure instance.
        
        If no actual value is present, a producer of such a structure instance should leave this member defaulted, and a consumer of such a structure instance should ignore the specific value stored in this member.
        """
        return self._value

    @Value.setter
    def Value(self, value: object) -> None:
        self._value = value


__all__ = ['Optional']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.inspection
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
from .x_property_control import XPropertyControl as XPropertyControl_3f260fe2


class LineDescriptor(object):
    """
    Struct Class

    describes the appearance of a line representing a single property in an ObjectInspector.
    
    Such a line consists of
    
    **since**
    
        OOo 2.0.3

    See Also:
        `API LineDescriptor <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1inspection_1_1LineDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.inspection'
    __ooo_full_ns__: str = 'com.sun.star.inspection.LineDescriptor'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.inspection.LineDescriptor'
    """Literal Constant ``com.sun.star.inspection.LineDescriptor``"""

    def __init__(self, DisplayName: typing.Optional[str] = '', Control: typing.Optional[XPropertyControl_3f260fe2] = None, HelpURL: typing.Optional[str] = '', HasPrimaryButton: typing.Optional[bool] = False, PrimaryButtonId: typing.Optional[str] = '', PrimaryButtonImageURL: typing.Optional[str] = '', PrimaryButtonImage: typing.Optional[XGraphic_a4da0afc] = None, HasSecondaryButton: typing.Optional[bool] = False, SecondaryButtonId: typing.Optional[str] = '', SecondaryButtonImageURL: typing.Optional[str] = '', SecondaryButtonImage: typing.Optional[XGraphic_a4da0afc] = None, IndentLevel: typing.Optional[int] = 0, Category: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            DisplayName (str, optional): DisplayName value.
            Control (XPropertyControl, optional): Control value.
            HelpURL (str, optional): HelpURL value.
            HasPrimaryButton (bool, optional): HasPrimaryButton value.
            PrimaryButtonId (str, optional): PrimaryButtonId value.
            PrimaryButtonImageURL (str, optional): PrimaryButtonImageURL value.
            PrimaryButtonImage (XGraphic, optional): PrimaryButtonImage value.
            HasSecondaryButton (bool, optional): HasSecondaryButton value.
            SecondaryButtonId (str, optional): SecondaryButtonId value.
            SecondaryButtonImageURL (str, optional): SecondaryButtonImageURL value.
            SecondaryButtonImage (XGraphic, optional): SecondaryButtonImage value.
            IndentLevel (int, optional): IndentLevel value.
            Category (str, optional): Category value.
        """
        super().__init__()

        if isinstance(DisplayName, LineDescriptor):
            oth: LineDescriptor = DisplayName
            self.DisplayName = oth.DisplayName
            self.Control = oth.Control
            self.HelpURL = oth.HelpURL
            self.HasPrimaryButton = oth.HasPrimaryButton
            self.PrimaryButtonId = oth.PrimaryButtonId
            self.PrimaryButtonImageURL = oth.PrimaryButtonImageURL
            self.PrimaryButtonImage = oth.PrimaryButtonImage
            self.HasSecondaryButton = oth.HasSecondaryButton
            self.SecondaryButtonId = oth.SecondaryButtonId
            self.SecondaryButtonImageURL = oth.SecondaryButtonImageURL
            self.SecondaryButtonImage = oth.SecondaryButtonImage
            self.IndentLevel = oth.IndentLevel
            self.Category = oth.Category
            return

        kargs = {
            "DisplayName": DisplayName,
            "Control": Control,
            "HelpURL": HelpURL,
            "HasPrimaryButton": HasPrimaryButton,
            "PrimaryButtonId": PrimaryButtonId,
            "PrimaryButtonImageURL": PrimaryButtonImageURL,
            "PrimaryButtonImage": PrimaryButtonImage,
            "HasSecondaryButton": HasSecondaryButton,
            "SecondaryButtonId": SecondaryButtonId,
            "SecondaryButtonImageURL": SecondaryButtonImageURL,
            "SecondaryButtonImage": SecondaryButtonImage,
            "IndentLevel": IndentLevel,
            "Category": Category,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._display_name = kwargs["DisplayName"]
        self._control = kwargs["Control"]
        self._help_url = kwargs["HelpURL"]
        self._has_primary_button = kwargs["HasPrimaryButton"]
        self._primary_button_id = kwargs["PrimaryButtonId"]
        self._primary_button_image_url = kwargs["PrimaryButtonImageURL"]
        self._primary_button_image = kwargs["PrimaryButtonImage"]
        self._has_secondary_button = kwargs["HasSecondaryButton"]
        self._secondary_button_id = kwargs["SecondaryButtonId"]
        self._secondary_button_image_url = kwargs["SecondaryButtonImageURL"]
        self._secondary_button_image = kwargs["SecondaryButtonImage"]
        self._indent_level = kwargs["IndentLevel"]
        self._category = kwargs["Category"]


    @property
    def DisplayName(self) -> str:
        """
        denotes the human-readable display name used to present a property to the user
        """
        return self._display_name

    @DisplayName.setter
    def DisplayName(self, value: str) -> None:
        self._display_name = value

    @property
    def Control(self) -> XPropertyControl_3f260fe2:
        """
        denotes the control which should be used to represent the property at the UI.
        """
        return self._control

    @Control.setter
    def Control(self, value: XPropertyControl_3f260fe2) -> None:
        self._control = value

    @property
    def HelpURL(self) -> str:
        """
        specifies the URL to the help topic to be associated with the property
        """
        return self._help_url

    @HelpURL.setter
    def HelpURL(self, value: str) -> None:
        self._help_url = value

    @property
    def HasPrimaryButton(self) -> bool:
        """
        determines whether a button exists which can be used for a more complex, interactive property value input.
        
        If no image for the primary button is specified, but a primary button is present, the three dots will be displayed on the button.
        """
        return self._has_primary_button

    @HasPrimaryButton.setter
    def HasPrimaryButton(self, value: bool) -> None:
        self._has_primary_button = value

    @property
    def PrimaryButtonId(self) -> str:
        """
        describes a unique id to associate with the primary button
        
        In OpenOffice.org, UI elements sometimes require a so-called UniqueID, which can be used to uniquely (within the whole application) identify this UI element. For instance, automating the OpenOffice.org UI via a dedicated separate application (\"TestTool\") requires such IDs.
        
        If a primary button exists for a property's UI representation (HasPrimaryButton), it gets the ID specified herein.
        """
        return self._primary_button_id

    @PrimaryButtonId.setter
    def PrimaryButtonId(self, value: str) -> None:
        self._primary_button_id = value

    @property
    def PrimaryButtonImageURL(self) -> str:
        """
        describes the URL of an image to display on the primary button, if any.
        
        This URL will be used to obtain an actual com.sun.star.graphic.XGraphic object from a com.sun.star.graphic.GraphicProvider.
        
        The property will be ignored if HasPrimaryButton is FALSE.
        
        If you need to specify a graphic which does not have a URL, but is available as com.sun.star.graphic.XGraphic only, then you must leave PrimaryButtonImageURL empty, and use the PrimaryButtonImage property.
        """
        return self._primary_button_image_url

    @PrimaryButtonImageURL.setter
    def PrimaryButtonImageURL(self, value: str) -> None:
        self._primary_button_image_url = value

    @property
    def PrimaryButtonImage(self) -> XGraphic_a4da0afc:
        """
        describes a graphics to display at the primary button, if any.
        
        The property will be ignored if HasPrimaryButton is FALSE, or if PrimaryButtonImageURL is a non-empty string.
        """
        return self._primary_button_image

    @PrimaryButtonImage.setter
    def PrimaryButtonImage(self, value: XGraphic_a4da0afc) -> None:
        self._primary_button_image = value

    @property
    def HasSecondaryButton(self) -> bool:
        """
        determines whether a secondary button exists which can be used for a more complex, interactive property value input.
        
        A secondary button subordinated to the primary button. If no primary button exists (HasPrimaryButton), this member is ignored.
        """
        return self._has_secondary_button

    @HasSecondaryButton.setter
    def HasSecondaryButton(self, value: bool) -> None:
        self._has_secondary_button = value

    @property
    def SecondaryButtonId(self) -> str:
        """
        describes a unique id to associate with the primary button
        
        If a secondary button exists for a property's UI representation (HasSecondaryButton), it gets the ID specified herein.
        """
        return self._secondary_button_id

    @SecondaryButtonId.setter
    def SecondaryButtonId(self, value: str) -> None:
        self._secondary_button_id = value

    @property
    def SecondaryButtonImageURL(self) -> str:
        """
        describes the URL of an image to display on the secondary button, if any.
        
        This URL will be used to obtain an actual com.sun.star.graphic.XGraphic object from a com.sun.star.graphic.GraphicProvider.
        
        The property will be ignored if HasSecondaryButton is FALSE.
        
        If you need to specify a graphic which does not have a URL, but is available as com.sun.star.graphic.XGraphic only, then you must leave SecondaryButtonImageURL empty, and use the SecondaryButtonImage property.
        """
        return self._secondary_button_image_url

    @SecondaryButtonImageURL.setter
    def SecondaryButtonImageURL(self, value: str) -> None:
        self._secondary_button_image_url = value

    @property
    def SecondaryButtonImage(self) -> XGraphic_a4da0afc:
        """
        describes a graphics to display at the secondary button, if any.
        
        The property will be ignored if HasSecondaryButton is FALSE, or if SecondaryButtonImageURL is a non-empty string.
        """
        return self._secondary_button_image

    @SecondaryButtonImage.setter
    def SecondaryButtonImage(self, value: XGraphic_a4da0afc) -> None:
        self._secondary_button_image = value

    @property
    def IndentLevel(self) -> int:
        """
        describes the indent level for the property
        
        If a given property semantically depends on another one, the indent level can be used to visually represent this fact. For this, the dependent property's indent level would be one larger than the indent level of the other property.
        
        Normally, XPropertyHandlers will set this to 0 when describing the UI for a normal property.
        """
        return self._indent_level

    @IndentLevel.setter
    def IndentLevel(self, value: int) -> None:
        self._indent_level = value

    @property
    def Category(self) -> str:
        """
        describes the category into which the property should be sorted by the ObjectInspector.
        
        An ObjectInspector can visually group properties which semantically belong together (for instance using tab pages). The decision which properties actually belong together is made using this Category attribute.
        
        For your implementation of XPropertyHandler, it's recommended that you document the programmatic names used for property categories. This way, your handler might be re-used in different contexts, where only the XObjectInspectorModel needs to provide consistent UI names for the categories.
        """
        return self._category

    @Category.setter
    def Category(self, value: str) -> None:
        self._category = value


__all__ = ['LineDescriptor']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.sax
from __future__ import annotations
import typing
from abc import abstractmethod
from ...io.x_active_data_source import XActiveDataSource as XActiveDataSource_d1900c7f
from .x_extended_document_handler import XExtendedDocumentHandler as XExtendedDocumentHandler_89231159

class XWriter(XActiveDataSource_d1900c7f, XExtendedDocumentHandler_89231159):
    """
    Provides a unified interface for the new-style Writer service to implement.
    
    **since**
    
        LibreOffice 4.0

    See Also:
        `API XWriter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XWriter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.sax.XWriter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.sax.XWriter'

    @abstractmethod
    def setCustomEntityNames(self, replacements: typing.Tuple[typing.Tuple[str, str], ...]) -> None:
        """
        Adds support for custom entity names list.
        
        **since**
        
            LibreOffice 7.2
        """
        ...

__all__ = ['XWriter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from ..container.x_child import XChild as XChild_a6390b07
from ..lang.x_multi_service_factory import XMultiServiceFactory as XMultiServiceFactory_191e0eb6
from .x_command_preparation import XCommandPreparation as XCommandPreparation_fad90ddd
from .x_queries_supplier import XQueriesSupplier as XQueriesSupplier_d4920ccb
from .xsql_query_composer_factory import XSQLQueryComposerFactory as XSQLQueryComposerFactory_42300fbf
from ..sdbc.connection import Connection as Connection_98fe0ab4
from ..sdbcx.database_definition import DatabaseDefinition as DatabaseDefinition_9d00e3a

class Connection(Connection_98fe0ab4, DatabaseDefinition_9d00e3a, XChild_a6390b07, XMultiServiceFactory_191e0eb6, XCommandPreparation_fad90ddd, XQueriesSupplier_d4920ccb, XSQLQueryComposerFactory_42300fbf):
    """
    Service Class

    extends the com.sun.star.sdbc.Connection of SDBC by providing the data definitions of a connected database.

    See Also:
        `API Connection <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1Connection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.Connection'
    __ooo_type_name__: str = 'service'


__all__ = ['Connection']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.linguistic2.conversion_dictionary import ConversionDictionary as ConversionDictionary
with suppress(ImportError):
    from ...dyn.linguistic2.conversion_dictionary_list import ConversionDictionaryList as ConversionDictionaryList
with suppress(ImportError):
    from ...dyn.linguistic2.conversion_dictionary_type import ConversionDictionaryType as ConversionDictionaryType
with suppress(ImportError):
    from ...dyn.linguistic2.conversion_dictionary_type import ConversionDictionaryTypeEnum as ConversionDictionaryTypeEnum
with suppress(ImportError):
    from ...dyn.linguistic2.conversion_direction import ConversionDirection as ConversionDirection
with suppress(ImportError):
    from ...dyn.linguistic2.conversion_property_type import ConversionPropertyType as ConversionPropertyType
with suppress(ImportError):
    from ...dyn.linguistic2.conversion_property_type import ConversionPropertyTypeEnum as ConversionPropertyTypeEnum
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary import Dictionary as Dictionary
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_event import DictionaryEvent as DictionaryEvent
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_event_flags import DictionaryEventFlags as DictionaryEventFlags
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_event_flags import DictionaryEventFlagsEnum as DictionaryEventFlagsEnum
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_list import DictionaryList as DictionaryList
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_list_event import DictionaryListEvent as DictionaryListEvent
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_list_event_flags import DictionaryListEventFlags as DictionaryListEventFlags
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_list_event_flags import DictionaryListEventFlagsEnum as DictionaryListEventFlagsEnum
with suppress(ImportError):
    from ...dyn.linguistic2.dictionary_type import DictionaryType as DictionaryType
with suppress(ImportError):
    from ...dyn.linguistic2.hangul_hanja_conversion_dictionary import HangulHanjaConversionDictionary as HangulHanjaConversionDictionary
with suppress(ImportError):
    from ...dyn.linguistic2.hyphenator import Hyphenator as Hyphenator
with suppress(ImportError):
    from ...dyn.linguistic2.language_guessing import LanguageGuessing as LanguageGuessing
with suppress(ImportError):
    from ...dyn.linguistic2.lingu_properties import LinguProperties as LinguProperties
with suppress(ImportError):
    from ...dyn.linguistic2.lingu_service_event import LinguServiceEvent as LinguServiceEvent
with suppress(ImportError):
    from ...dyn.linguistic2.lingu_service_event_flags import LinguServiceEventFlags as LinguServiceEventFlags
with suppress(ImportError):
    from ...dyn.linguistic2.lingu_service_event_flags import LinguServiceEventFlagsEnum as LinguServiceEventFlagsEnum
with suppress(ImportError):
    from ...dyn.linguistic2.lingu_service_manager import LinguServiceManager as LinguServiceManager
with suppress(ImportError):
    from ...dyn.linguistic2.number_text import NumberText as NumberText
with suppress(ImportError):
    from ...dyn.linguistic2.proofreader import Proofreader as Proofreader
with suppress(ImportError):
    from ...dyn.linguistic2.proofreading_iterator import ProofreadingIterator as ProofreadingIterator
with suppress(ImportError):
    from ...dyn.linguistic2.proofreading_result import ProofreadingResult as ProofreadingResult
with suppress(ImportError):
    from ...dyn.linguistic2.single_proofreading_error import SingleProofreadingError as SingleProofreadingError
with suppress(ImportError):
    from ...dyn.linguistic2.spell_checker import SpellChecker as SpellChecker
with suppress(ImportError):
    from ...dyn.linguistic2.spell_failure import SpellFailure as SpellFailure
with suppress(ImportError):
    from ...dyn.linguistic2.spell_failure import SpellFailureEnum as SpellFailureEnum
with suppress(ImportError):
    from ...dyn.linguistic2.thesaurus import Thesaurus as Thesaurus
with suppress(ImportError):
    from ...dyn.linguistic2.x_available_locales import XAvailableLocales as XAvailableLocales
with suppress(ImportError):
    from ...dyn.linguistic2.x_conversion_dictionary import XConversionDictionary as XConversionDictionary
with suppress(ImportError):
    from ...dyn.linguistic2.x_conversion_dictionary_list import XConversionDictionaryList as XConversionDictionaryList
with suppress(ImportError):
    from ...dyn.linguistic2.x_conversion_property_type import XConversionPropertyType as XConversionPropertyType
with suppress(ImportError):
    from ...dyn.linguistic2.x_dictionary import XDictionary as XDictionary
with suppress(ImportError):
    from ...dyn.linguistic2.x_dictionary1 import XDictionary1 as XDictionary1
with suppress(ImportError):
    from ...dyn.linguistic2.x_dictionary_entry import XDictionaryEntry as XDictionaryEntry
with suppress(ImportError):
    from ...dyn.linguistic2.x_dictionary_event_listener import XDictionaryEventListener as XDictionaryEventListener
with suppress(ImportError):
    from ...dyn.linguistic2.x_dictionary_list import XDictionaryList as XDictionaryList
with suppress(ImportError):
    from ...dyn.linguistic2.x_dictionary_list_event_listener import XDictionaryListEventListener as XDictionaryListEventListener
with suppress(ImportError):
    from ...dyn.linguistic2.x_hyphenated_word import XHyphenatedWord as XHyphenatedWord
with suppress(ImportError):
    from ...dyn.linguistic2.x_hyphenator import XHyphenator as XHyphenator
with suppress(ImportError):
    from ...dyn.linguistic2.x_language_guessing import XLanguageGuessing as XLanguageGuessing
with suppress(ImportError):
    from ...dyn.linguistic2.x_lingu_properties import XLinguProperties as XLinguProperties
with suppress(ImportError):
    from ...dyn.linguistic2.x_lingu_service_event_broadcaster import XLinguServiceEventBroadcaster as XLinguServiceEventBroadcaster
with suppress(ImportError):
    from ...dyn.linguistic2.x_lingu_service_event_listener import XLinguServiceEventListener as XLinguServiceEventListener
with suppress(ImportError):
    from ...dyn.linguistic2.x_lingu_service_manager import XLinguServiceManager as XLinguServiceManager
with suppress(ImportError):
    from ...dyn.linguistic2.x_lingu_service_manager2 import XLinguServiceManager2 as XLinguServiceManager2
with suppress(ImportError):
    from ...dyn.linguistic2.x_meaning import XMeaning as XMeaning
with suppress(ImportError):
    from ...dyn.linguistic2.x_number_text import XNumberText as XNumberText
with suppress(ImportError):
    from ...dyn.linguistic2.x_possible_hyphens import XPossibleHyphens as XPossibleHyphens
with suppress(ImportError):
    from ...dyn.linguistic2.x_proofreader import XProofreader as XProofreader
with suppress(ImportError):
    from ...dyn.linguistic2.x_proofreading_iterator import XProofreadingIterator as XProofreadingIterator
with suppress(ImportError):
    from ...dyn.linguistic2.x_searchable_dictionary import XSearchableDictionary as XSearchableDictionary
with suppress(ImportError):
    from ...dyn.linguistic2.x_searchable_dictionary_list import XSearchableDictionaryList as XSearchableDictionaryList
with suppress(ImportError):
    from ...dyn.linguistic2.x_set_spell_alternatives import XSetSpellAlternatives as XSetSpellAlternatives
with suppress(ImportError):
    from ...dyn.linguistic2.x_spell_alternatives import XSpellAlternatives as XSpellAlternatives
with suppress(ImportError):
    from ...dyn.linguistic2.x_spell_checker import XSpellChecker as XSpellChecker
with suppress(ImportError):
    from ...dyn.linguistic2.x_spell_checker1 import XSpellChecker1 as XSpellChecker1
with suppress(ImportError):
    from ...dyn.linguistic2.x_supported_languages import XSupportedLanguages as XSupportedLanguages
with suppress(ImportError):
    from ...dyn.linguistic2.x_supported_locales import XSupportedLocales as XSupportedLocales
with suppress(ImportError):
    from ...dyn.linguistic2.x_thesaurus import XThesaurus as XThesaurus



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ui
from __future__ import annotations
import typing
from abc import abstractproperty
from .ui_element import UIElement as UIElement_78af094e
from .xui_element_settings import XUIElementSettings as XUIElementSettings_ddbb0cf7
if typing.TYPE_CHECKING:
    from .xui_configuration_manager import XUIConfigurationManager as XUIConfigurationManager_24e20eef

class ConfigurableUIElement(UIElement_78af094e, XUIElementSettings_ddbb0cf7):
    """
    Service Class

    specifies a configurable user interface element that supports persistence.
    
    Configurable user interface elements are:
    
    **since**
    
        OOo 2.0

    See Also:
        `API ConfigurableUIElement <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ui_1_1ConfigurableUIElement.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ui'
    __ooo_full_ns__: str = 'com.sun.star.ui.ConfigurableUIElement'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ConfigurationSource(self) -> XUIConfigurationManager_24e20eef:
        """
        specifies the configuration source of this user interface element.
        
        If the property Persistent is TRUE changes on the structure of the user interface element are written back to configuration source. When this property is changed, afterwards XUIElementSettings.updateSettings() must be called so the user interface element tries to retrieve its settings from the new user interface configuration manager.
        """
        ...

    @abstractproperty
    def Persistent(self) -> bool:
        """
        specifies if the user interface element stores changes of its structure to its creator source defined by the property ConfigurationSource.
        """
        ...


__all__ = ['ConfigurableUIElement']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from .x_dependent_text_field import XDependentTextField as XDependentTextField_c3d0e45

class TextFieldMaster(XPropertySet_bc180bfa):
    """
    Service Class

    A TextFieldMaster specifies important data for its DependentTextFields.

    See Also:
        `API TextFieldMaster <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextFieldMaster.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TextFieldMaster'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DependentTextFields(self) -> typing.Tuple[XDependentTextField_c3d0e45, ...]:
        """
        contains a sequence of all fields that depend on this master.
        """
        ...

    @abstractproperty
    def InstanceName(self) -> str:
        """
        contains the instance name as it is used in the com.sun.star.text.XTextFieldsSupplier.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        determines the name of the field master.
        
        The name is void as long as the instance is not member of the document structure. When the value is being set the instance is inserted into the document and the name cannot be changed afterwards. That does not apply to the Database text field master.
        """
        ...


__all__ = ['TextFieldMaster']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.table


class CellJustifyMethod(object):
    """
    Const Class

    Specifies how text inside a cell is justified.
    
    The justification methods closely follow the methods described under the text-justify property of the CSS Text Level 3 specification. The latest version of the aforementioned specification is found here http://www.w3.org/TR/css3-text/.

    See Also:
        `API CellJustifyMethod <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1table_1_1CellJustifyMethod.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.table'
    __ooo_full_ns__: str = 'com.sun.star.table.CellJustifyMethod'
    __ooo_type_name__: str = 'const'

    AUTO = 0
    """
    Automatic.
    """
    DISTRIBUTE = 1
    """
    When applied in the direction of text flow, characters in each line are distributed at equal intervals so that the ends of each line are aligned with the start and end edges of the cell.
    
    When applied in the perpendicular direction of text flow, the lines are distributed at equal intervals so that the first and last lines are aligned with the start and end edges of the cell.
    """

__all__ = ['CellJustifyMethod']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sdb.application
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class NamedDatabaseObject(object):
    """
    Struct Class

    denotes a named database object, or a named folder of database objects
    
    **since**
    
        OOo 3.0

    See Also:
        `API NamedDatabaseObject <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sdb_1_1application_1_1NamedDatabaseObject.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb.application'
    __ooo_full_ns__: str = 'com.sun.star.sdb.application.NamedDatabaseObject'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sdb.application.NamedDatabaseObject'
    """Literal Constant ``com.sun.star.sdb.application.NamedDatabaseObject``"""

    def __init__(self, Type: typing.Optional[int] = 0, Name: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Type (int, optional): Type value.
            Name (str, optional): Name value.
        """
        super().__init__()

        if isinstance(Type, NamedDatabaseObject):
            oth: NamedDatabaseObject = Type
            self.Type = oth.Type
            self.Name = oth.Name
            return

        kargs = {
            "Type": Type,
            "Name": Name,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._type = kwargs["Type"]
        self._name = kwargs["Name"]


    @property
    def Type(self) -> int:
        """
        denotes the type of the object.
        
        This member is one of the DatabaseObject or DatabaseObjectContainer constants.
        """
        return self._type

    @Type.setter
    def Type(self, value: int) -> None:
        self._type = value

    @property
    def Name(self) -> str:
        """
        denotes the name of the object
        
        In case of forms, reports, form folders and report folders, this is the hierarchical path to the object, where the path elements are separated by a slash (/).
        
        In case of tables, this is the fully qualified name of the table, as required by the database's table name composition rules.
        
        In case of queries, this is the name of the query.
        
        In case of virtual folders denoted by DatabaseObjectContainer.CATALOG and DatabaseObjectContainer.SCHEMA, it is
        
        In case of the virtual folders denoted by DatabaseObjectContainer.TABLES, DatabaseObjectContainer.QUERIES, DatabaseObjectContainer.DATA_SOURCE, DatabaseObjectContainer.FORMS or DatabaseObjectContainer.REPORTS, this denotes the name of the data source (as denoted by com.sun.star.sdb.DataSource.Name)
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value


__all__ = ['NamedDatabaseObject']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.binding
from __future__ import annotations
from .bindable_data_aware_control_model import BindableDataAwareControlModel as BindableDataAwareControlModel_47091512
from ..component.database_date_field import DatabaseDateField as DatabaseDateField_8b891134

class BindableDatabaseDateField(BindableDataAwareControlModel_47091512, DatabaseDateField_8b891134):
    """
    Service Class

    This service specifies a date input field which is data-aware and thus can be bound to a database field, and additionally supports binding to arbitrary external values.
    
    If a com.sun.star.form.binding.ValueBinding instance is set at the field, it will exchange it's content with the binding as com.sun.star.util.Date.

    See Also:
        `API BindableDatabaseDateField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1binding_1_1BindableDatabaseDateField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.BindableDatabaseDateField'
    __ooo_type_name__: str = 'service'


__all__ = ['BindableDatabaseDateField']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .chart_data_value import ChartDataValue as ChartDataValue_d3310c83


class ChartDataRow(object):
    """
    Struct Class

    describes a single data row, specified by its name and a sequence of data points.
    
    This struct is currently used nowhere.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API ChartDataRow <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart_1_1ChartDataRow.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartDataRow'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart.ChartDataRow'
    """Literal Constant ``com.sun.star.chart.ChartDataRow``"""

    def __init__(self, Points: typing.Optional[typing.Tuple[typing.Tuple[ChartDataValue_d3310c83, ...], ...]] = (), Name: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            Points (typing.Tuple[typing.Tuple[ChartDataValue, ...], ...], optional): Points value.
            Name (str, optional): Name value.
        """
        super().__init__()

        if isinstance(Points, ChartDataRow):
            oth: ChartDataRow = Points
            self.Points = oth.Points
            self.Name = oth.Name
            return

        kargs = {
            "Points": Points,
            "Name": Name,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._points = kwargs["Points"]
        self._name = kwargs["Name"]


    @property
    def Points(self) -> typing.Tuple[typing.Tuple[ChartDataValue_d3310c83, ...], ...]:
        """
        The points contained in this data row.
        """
        return self._points

    @Points.setter
    def Points(self, value: typing.Tuple[typing.Tuple[ChartDataValue_d3310c83, ...], ...]) -> None:
        self._points = value

    @property
    def Name(self) -> str:
        """
        The name of the data row.
        """
        return self._name

    @Name.setter
    def Name(self, value: str) -> None:
        self._name = value


__all__ = ['ChartDataRow']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .search_options import SearchOptions as SearchOptions_bd140c08
    from .search_result import SearchResult as SearchResult_b1070b9b

class XTextSearch(XInterface_8f010a43):
    """
    enables an object to search in its content.

    See Also:
        `API XTextSearch <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XTextSearch.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XTextSearch'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XTextSearch'

    @abstractmethod
    def searchBackward(self, searchStr: str, startPos: int, endPos: int) -> SearchResult_b1070b9b:
        """
        search backward in the searchStr, starts at startPos and ends by endpos.
        
        The endpos must be lower than the startpos, because the function searches backward! The result is returned in the SearchResult.
        """
        ...
    @abstractmethod
    def searchForward(self, searchStr: str, startPos: int, endPos: int) -> SearchResult_b1070b9b:
        """
        search forward in the searchStr, starts at startPos and ends by endpos.
        
        The result is returned in the SearchResult.
        """
        ...
    @abstractmethod
    def setOptions(self, options: SearchOptions_bd140c08) -> None:
        """
        set the options for the forward or backward search.
        """
        ...

__all__ = ['XTextSearch']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.configuration.backend
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_layer import XLayer as XLayer_4cd50fcb
    from .x_updatable_layer import XUpdatableLayer as XUpdatableLayer_ec97135d

class XSingleLayerStratum(XInterface_8f010a43):
    """
    Handles access to a stratum consisting of a single layer in a configuration data repository.
    
    The interface provides timestamp-checking capabilities for efficient caching.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XSingleLayerStratum <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1configuration_1_1backend_1_1XSingleLayerStratum.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.configuration.backend'
    __ooo_full_ns__: str = 'com.sun.star.configuration.backend.XSingleLayerStratum'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.configuration.backend.XSingleLayerStratum'

    @abstractmethod
    def getLayer(self, aComponent: str, aTimestamp: str) -> XLayer_4cd50fcb:
        """
        retrieves the layer data for a component, if newer than indicated.
        
        A timestamp can be provided, which is used to indicate a point in time. The layer should be returned only if is modified since that time.
        
        An empty timestamp indicates, that the layer should be retrieved irrespective of its modification time.
        
        The format and meaning of a timestamp depends on the implementation. Timestamps can be obtained using com.sun.star.util.XTimeStamped.getTimestamp().

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getUpdatableLayer(self, aComponent: str) -> XUpdatableLayer_ec97135d:
        """
        retrieves a writable representation of the layer for a component.

        Raises:
            BackendAccessException: ``BackendAccessException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XSingleLayerStratum']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class Document(XPropertySet_bc180bfa):
    """
    Service Class

    specifies documents which belong to a database source.
    
    These documents typically process information from a connected data source. A Document could be a form or a report.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API Document <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1Document.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.Document'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DocumentLocation(self) -> str:
        """
        is the URL of the document.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        is the name of the document.
        
        If the document is part of the container, it is not possible to alter the name.
        """
        ...


__all__ = ['Document']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.presentation
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.presentation.ClickAction import ClickActionProto

class ClickAction(Enum):
    """
    Enum Class


    See Also:
        `API ClickAction <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8f>`_
    """
    __ooo_ns__: str = 'com.sun.star.presentation'
    __ooo_full_ns__: str = 'com.sun.star.presentation.ClickAction'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.presentation.ClickAction'

    BOOKMARK = cast("ClickActionProto", 'BOOKMARK')
    """
    The presentation jumps to a bookmark.
    """
    DOCUMENT = cast("ClickActionProto", 'DOCUMENT')
    """
    The presentation jumps to another document.
    """
    FIRSTPAGE = cast("ClickActionProto", 'FIRSTPAGE')
    """
    The presentation continues with the first page.
    """
    INVISIBLE = cast("ClickActionProto", 'INVISIBLE')
    """
    The object renders itself invisible after a click.
    """
    LASTPAGE = cast("ClickActionProto", 'LASTPAGE')
    """
    The presentation continues with the last page.
    """
    MACRO = cast("ClickActionProto", 'MACRO')
    """
    A star basic macro is executed after the click.
    """
    NEXTPAGE = cast("ClickActionProto", 'NEXTPAGE')
    """
    The presentation jumps to the next page.
    """
    NONE = cast("ClickActionProto", 'NONE')
    """
    use no animation effects.
    
    use no fade effects.
    
    No action is performed on click.
    """
    PREVPAGE = cast("ClickActionProto", 'PREVPAGE')
    """
    The presentation jumps to the previous page.
    """
    PROGRAM = cast("ClickActionProto", 'PROGRAM')
    """
    Another program is executed after a click.
    """
    SOUND = cast("ClickActionProto", 'SOUND')
    """
    A sound is played after a click.
    """
    STOPPRESENTATION = cast("ClickActionProto", 'STOPPRESENTATION')
    """
    The presentation is stopped after the click.
    """
    VANISH = cast("ClickActionProto", 'VANISH')
    """
    The object vanishes with its effect.
    """
    VERB = cast("ClickActionProto", 'VERB')
    """
    An OLE verb is performed on this object.
    """

__all__ = ['ClickAction']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
    from .x_frame import XFrame as XFrame_7a570956
    from .x_terminate_listener import XTerminateListener as XTerminateListener_b760e5a
    from ..lang.x_component import XComponent as XComponent_98dc0ab5

class XDesktop(XInterface_8f010a43):
    """
    This is the main interface of a desktop service.
    
    A desktop is an environment for components which can be viewed in frames. Frames are like frames in HTML framesets. This does not imply that a desktop can handle framesets; the frames may be top frames only.

    See Also:
        `API XDesktop <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XDesktop.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XDesktop'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XDesktop'

    @abstractmethod
    def addTerminateListener(self, Listener: XTerminateListener_b760e5a) -> None:
        """
        registers an event listener to the desktop, which is called when the desktop is queried to terminate, and when it really terminates.
        """
        ...
    @abstractmethod
    def getComponents(self) -> XEnumerationAccess_4bac0ffc:
        """
        provides read access to collection of all currently loaded components inside the frame tree
        
        The component is, by definition, the model of the control which is loaded into a frame, or if no model exists, into the control itself. The service Components which is available from this method is a collection of all components of the desktop which are open within a frame of the desktop.
        """
        ...
    @abstractmethod
    def getCurrentComponent(self) -> XComponent_98dc0ab5:
        """
        provides read access to the component inside the tree which has the UI focus
        
        Normally, the component is the model part of the active component. If no model exists it is the active controller (view) itself.
        """
        ...
    @abstractmethod
    def getCurrentFrame(self) -> XFrame_7a570956:
        """
        provides read access to the frame which contains the current component
        """
        ...
    @abstractmethod
    def removeTerminateListener(self, Listener: XTerminateListener_b760e5a) -> None:
        """
        unregisters an event listener for termination events.
        """
        ...
    @abstractmethod
    def terminate(self) -> bool:
        """
        tries to terminate the desktop.
        
        First, every terminate listener is called by his XTerminateListener.queryTermination() method. Throwing of a TerminationVetoException can break the termination process and the listener how has done that will be the new \"controller\" of the desktop lifetime. He should try to terminate it by himself after his own processes will be finished. If nobody disagree with the termination request, every listener will be called by his XTerminateListener.notifyTermination() method.
        """
        ...

__all__ = ['XDesktop']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..chart.x_chart_data_array import XChartDataArray as XChartDataArray_df4c0cdd
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from .sheet_ranges_query import SheetRangesQuery as SheetRangesQuery_efbe0d90
from .x_sheet_cell_range_container import XSheetCellRangeContainer as XSheetCellRangeContainer_661f1082
from .x_sheet_operation import XSheetOperation as XSheetOperation_e1f50d23
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..table.cell_properties import CellProperties as CellProperties_d4360cbd
from ..util.x_indent import XIndent as XIndent_7b290980
from ..util.x_replaceable import XReplaceable as XReplaceable_b0750b6e
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries_694810c0

class SheetCellRanges(SheetRangesQuery_efbe0d90, CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, CellProperties_d4360cbd, XChartDataArray_df4c0cdd, XEnumerationAccess_4bac0ffc, XNameContainer_cb90e47, XSheetCellRangeContainer_661f1082, XSheetOperation_e1f50d23, XIndent_7b290980, XReplaceable_b0750b6e):
    """
    Service Class

    represents a collection of cell ranges in a spreadsheet document.

    See Also:
        `API SheetCellRanges <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCellRanges.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SheetCellRanges'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AbsoluteName(self) -> str:
        """
        Returns the absolute address of the ranges as string, e.g.
        
        \"$Sheet1.$B$2:$D$5\".
        """
        ...

    @abstractproperty
    def ConditionalFormat(self) -> XSheetConditionalEntries_694810c0:
        """
        contains the conditional formatting settings for this cell.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def ConditionalFormatLocal(self) -> XSheetConditionalEntries_694810c0:
        """
        contains the conditional formatting settings for this cell, using localized formulas.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def Validation(self) -> XPropertySet_bc180bfa:
        """
        contains the data validation settings for this cell.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def ValidationLocal(self) -> XPropertySet_bc180bfa:
        """
        contains the data validation settings for this cell, using localized formulas.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """
        ...


__all__ = ['SheetCellRanges']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.vba
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class VBAScriptEventId(metaclass=UnoConstMeta, type_name="com.sun.star.script.vba.VBAScriptEventId", name_space="com.sun.star.script.vba"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.script.vba.VBAScriptEventId``"""
        pass

    class VBAScriptEventIdEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.script.vba.VBAScriptEventId", name_space="com.sun.star.script.vba"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.script.vba.VBAScriptEventId`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.script.vba import VBAScriptEventId as VBAScriptEventId
    else:
        # keep document generators happy
        from ....lo.script.vba.vba_script_event_id import VBAScriptEventId as VBAScriptEventId

    class VBAScriptEventIdEnum(IntEnum):
        """
        Enum of Const Class VBAScriptEventId

        Identifies a VBA script event fired via XVBACompatibility.broadcastVBAScriptEvent(), and received by XVBAScriptListener.notifyVBAScriptEvent().
        """
        SCRIPT_STARTED = VBAScriptEventId.SCRIPT_STARTED
        """
        This event is fired when a VBA script in the current document has been started.
        
        Several scripts may run simultaneously, e.g. when a running script triggers a document event that starts another script.
        
        The number of running scripts can be obtained via XVBACompatibility.RunningVBAScripts. The number returned there will already contain the new script notified with this event.
        
        The member VBAScriptEvent.ModuleName of the event object will contain the name of the code module that contains the started script.
        """
        SCRIPT_STOPPED = VBAScriptEventId.SCRIPT_STOPPED
        """
        This event is fired when a VBA script in the current document stops running.
        
        Several scripts may run simultaneously, e.g. when a running script triggers a document event that starts another script.
        
        The number of scripts still running can be obtained via XVBACompatibility.RunningVBAScripts. The number returned there will not contain the stopped script notified with this event anymore.
        
        The member VBAScriptEvent.ModuleName of the event object will contain the name of the code module that contains the script that has been stopped.
        """
        INITIALIZE_USERFORM = VBAScriptEventId.INITIALIZE_USERFORM
        """
        This event is fired when a VBA script in the current document tries to instantiate a userform.
        
        The member VBAScriptEvent.ModuleName of the event object will contain the name of the userform module.
        """

__all__ = ['VBAScriptEventId', 'VBAScriptEventIdEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
from abc import abstractmethod
from ..container.x_child import XChild as XChild_a6390b07
from ..util.x_lockable import XLockable as XLockable_8f330a3b
if typing.TYPE_CHECKING:
    from .x_undo_action import XUndoAction as XUndoAction_d6580cb3
    from .x_undo_manager_listener import XUndoManagerListener as XUndoManagerListener_5a3b1056

class XUndoManager(XChild_a6390b07, XLockable_8f330a3b):
    """
    provides access to the undo/redo stacks of a document
    
    Changes to a document usually result in recording of information how to undo those changes, if desired. A so-called undo action records the information how to undo a single change. Undo actions are maintained in a stack, so that the changes they represent can be undo in the reverse order they have originally been applied.
    
    Additionally, the Undo manager manages a Redo stack: Actions which are undone are moved from the Undo to the Redo stack, so it is possible to re-apply the changes to the document.
    
    For collecting multiple changes in a single undo action, so-called Undo contexts are provided. When an Undo context is entered, all subsequently added Undo actions are not pushed onto the undo stack directly, but considered a sub action of the Undo context. Once the Undo context is left, a single undo action is pushed onto the undo stack, which comprises all those single Undo actions.Undo contexts can be arbitrarily nested.
    
    Hidden Undo actions are those which in no observable way contribute to the undo stack. That is, any method retrieving information about the stack will behave as if the undo action does not exist. Nonetheless, calling undo() respectively redo() will include those actions.Hidden Undo actions can be created by calling enterHiddenUndoContext(), following by leaveUndoContext().
    
    An Undo manager can be locked and unlocked, using the XLockable.lock() and XLockable.unlock() methods. When it is locked, then every attempt to add an undo action, or to enter or leave an Undo context, will be silently ignored.
    
    **since**
    
        OOo 3.4

    See Also:
        `API XUndoManager <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XUndoManager.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XUndoManager'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XUndoManager'

    @abstractmethod
    def addUndoAction(self, iAction: XUndoAction_d6580cb3) -> None:
        """
        adds the given undo action to the undo stack.
        
        The redo stack is cleared when a new action is pushed onto the undo stack.
        
        The Undo manager takes ownership of any actions pushed onto the undo stack. This means that if the action is finally removed from the Undo manager's control (e.g. by calling clear() resp. clearRedo()), it will be disposed, as long as it supports the com.sun.star.lang.XComponent interface.
        
        If the Undo manager is locked at the moment the method is called, the call will be ignored, and the undo action will immediately be disposed, if applicable.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def addUndoManagerListener(self, iListener: XUndoManagerListener_5a3b1056) -> None:
        """
        adds a listener to be notified of changes in the Undo/Redo stacks.
        """
        ...
    @abstractmethod
    def clear(self) -> None:
        """
        clears the undo and the redo stack.
        
        All actions will be removed from both the Undo and the Redo stack. Actions which implement the com.sun.star.lang.XComponent interface will be disposed.

        Raises:
            com.sun.star.document.UndoContextNotClosedException: ``UndoContextNotClosedException``
        """
        ...
    @abstractmethod
    def clearRedo(self) -> None:
        """
        clears the redo stack.
        
        All actions will be removed from the Redo stack. Actions which implement the com.sun.star.lang.XComponent interface will be disposed.

        Raises:
            com.sun.star.document.UndoContextNotClosedException: ``UndoContextNotClosedException``
        """
        ...
    @abstractmethod
    def enterHiddenUndoContext(self) -> None:
        """
        enters a new undo context, creating a hidden undo action.
        
        A hidden undo action does not, in any visible way, contribute to the undo stack. This means that
        
        A new undo action will be added to the undo stack. As long as the context is not left, every undo action added to the stack will be treated as sub action. This means it will not be directly accessible at the undo manager, not appear in any user interface, and cannot be separately undone or re-done.
        
        Each call to enterHiddenUndoContext must be paired by a call to leaveUndoContext(), otherwise, the document's undo stack is left in an inconsistent state.
        
        Undo contexts can be nested, i.e. it is legitimate to call enterUndoContext() and enterHiddenUndoContext multiple times without calling leaveUndoContext() inbetween.

        Raises:
            EmptyUndoStackException: ``EmptyUndoStackException``
        """
        ...
    @abstractmethod
    def enterUndoContext(self, iTitle: str) -> None:
        """
        enters a new undo context.
        
        A new undo action will be added to the undo stack, with the title given as iTitle. As long as the context is not left, every undo action added to the stack will be treated as sub action. This means it will not be directly accessible at the Undo manager, not appear in any user interface, and cannot be separately undone or re-done.
        
        Each call to enterUndoContext must be paired by a call to leaveUndoContext(), otherwise, the document's undo stack is left in an inconsistent state.
        
        Undo contexts can be nested, i.e. it is legitimate to call enterUndoContext and enterHiddenUndoContext() multiple times without calling leaveUndoContext() inbetween.
        """
        ...
    @abstractmethod
    def getAllRedoActionTitles(self) -> typing.Tuple[str, ...]:
        """
        returns the titles of all actions currently on the Redo stack, from top to bottom
        """
        ...
    @abstractmethod
    def getAllUndoActionTitles(self) -> typing.Tuple[str, ...]:
        """
        returns the titles of all actions currently on the undo stack, from top to bottom
        """
        ...
    @abstractmethod
    def getCurrentRedoActionTitle(self) -> str:
        """
        returns the title of the top-most action on the Redo stack

        Raises:
            com.sun.star.document.EmptyUndoStackException: ``EmptyUndoStackException``
        """
        ...
    @abstractmethod
    def getCurrentUndoActionTitle(self) -> str:
        """
        returns the title of the top-most action on the undo stack

        Raises:
            com.sun.star.document.EmptyUndoStackException: ``EmptyUndoStackException``
        """
        ...
    @abstractmethod
    def isRedoPossible(self) -> bool:
        """
        determines whether redo() can reasonably be expected to succeed.
        """
        ...
    @abstractmethod
    def isUndoPossible(self) -> bool:
        """
        determines whether undo() can reasonably be expected to succeed.
        """
        ...
    @abstractmethod
    def leaveUndoContext(self) -> None:
        """
        leaves the undo context previously opened via enterUndoContext() respectively enterHiddenUndoContext().
        
        If no undo action has been added since the context has been opened, the context is not only left, but silently removed, and does not contribute to the undo stack at all. In this case, possible listeners will be notified via XUndoManagerListener.cancelledContext().
        
        Otherwise, the undo context will be closed, and added to the Undo stack; the redo stack will be cleared, and listeners will be notified via XUndoManagerListener.leftContext() resp. XUndoManagerListener.leftHiddenContext()

        Raises:
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...
    @abstractmethod
    def redo(self) -> None:
        """
        replays the action on the document which has most recently been undone
        
        Effectively, invoking this method will

        Raises:
            com.sun.star.document.EmptyUndoStackException: ``EmptyUndoStackException``
            com.sun.star.document.UndoContextNotClosedException: ``UndoContextNotClosedException``
            com.sun.star.document.UndoFailedException: ``UndoFailedException``
        """
        ...
    @abstractmethod
    def removeUndoManagerListener(self, iListener: XUndoManagerListener_5a3b1056) -> None:
        """
        removes a previously added listener
        """
        ...
    @abstractmethod
    def reset(self) -> None:
        """
        resets the Undo manager
        
        In particular, this method will
        
        Note that possible listeners will not get notifications for the single parts of the reset, i.e. there will be no single XUndoManagerListener.allActionsCleared(), XUndoManagerListener.leftContext(), etc., notifications. Instead, listeners will be notified of the reset by calling their XUndoManagerListener.resetAll() method.
        """
        ...
    @abstractmethod
    def undo(self) -> None:
        """
        reverts the most recent action on the document.
        
        Effectively, invoking this method will

        Raises:
            com.sun.star.document.EmptyUndoStackException: ``EmptyUndoStackException``
            com.sun.star.document.UndoContextNotClosedException: ``UndoContextNotClosedException``
            com.sun.star.document.UndoFailedException: ``UndoFailedException``
        """
        ...

__all__ = ['XUndoManager']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_single_select_query_composer import XSingleSelectQueryComposer as XSingleSelectQueryComposer_66e310b9

class OrderDialog(XExecutableDialog_450f0fa1):
    """
    Service Class

    This interface could be incomplete since I derived it from its places of use.
    
    **since**
    
        LibreOffice 4.1

    See Also:
        `API OrderDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1OrderDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.OrderDialog'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def createDefault(self) -> None:
        """
        """
        ...
    @abstractmethod
    def createWithQuery(self, QueryComposer: XSingleSelectQueryComposer_66e310b9, RowSet: XPropertySet_bc180bfa, ParentWindow: XWindow_713b0924) -> None:
        """
        """
        ...

__all__ = ['OrderDialog']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class IOErrorCode(metaclass=UnoEnumMeta, type_name="com.sun.star.ucb.IOErrorCode", name_space="com.sun.star.ucb"):
        """Dynamically created class that represents ``com.sun.star.ucb.IOErrorCode`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.ucb.IOErrorCode import ABORT as I_O_ERROR_CODE_ABORT
        from com.sun.star.ucb.IOErrorCode import ACCESS_DENIED as I_O_ERROR_CODE_ACCESS_DENIED
        from com.sun.star.ucb.IOErrorCode import ALREADY_EXISTING as I_O_ERROR_CODE_ALREADY_EXISTING
        from com.sun.star.ucb.IOErrorCode import BAD_CRC as I_O_ERROR_CODE_BAD_CRC
        from com.sun.star.ucb.IOErrorCode import CANT_CREATE as I_O_ERROR_CODE_CANT_CREATE
        from com.sun.star.ucb.IOErrorCode import CANT_READ as I_O_ERROR_CODE_CANT_READ
        from com.sun.star.ucb.IOErrorCode import CANT_SEEK as I_O_ERROR_CODE_CANT_SEEK
        from com.sun.star.ucb.IOErrorCode import CANT_TELL as I_O_ERROR_CODE_CANT_TELL
        from com.sun.star.ucb.IOErrorCode import CANT_WRITE as I_O_ERROR_CODE_CANT_WRITE
        from com.sun.star.ucb.IOErrorCode import CURRENT_DIRECTORY as I_O_ERROR_CODE_CURRENT_DIRECTORY
        from com.sun.star.ucb.IOErrorCode import DEVICE_NOT_READY as I_O_ERROR_CODE_DEVICE_NOT_READY
        from com.sun.star.ucb.IOErrorCode import DIFFERENT_DEVICES as I_O_ERROR_CODE_DIFFERENT_DEVICES
        from com.sun.star.ucb.IOErrorCode import GENERAL as I_O_ERROR_CODE_GENERAL
        from com.sun.star.ucb.IOErrorCode import INVALID_ACCESS as I_O_ERROR_CODE_INVALID_ACCESS
        from com.sun.star.ucb.IOErrorCode import INVALID_CHARACTER as I_O_ERROR_CODE_INVALID_CHARACTER
        from com.sun.star.ucb.IOErrorCode import INVALID_DEVICE as I_O_ERROR_CODE_INVALID_DEVICE
        from com.sun.star.ucb.IOErrorCode import INVALID_LENGTH as I_O_ERROR_CODE_INVALID_LENGTH
        from com.sun.star.ucb.IOErrorCode import INVALID_PARAMETER as I_O_ERROR_CODE_INVALID_PARAMETER
        from com.sun.star.ucb.IOErrorCode import IS_WILDCARD as I_O_ERROR_CODE_IS_WILDCARD
        from com.sun.star.ucb.IOErrorCode import LOCKING_VIOLATION as I_O_ERROR_CODE_LOCKING_VIOLATION
        from com.sun.star.ucb.IOErrorCode import MISPLACED_CHARACTER as I_O_ERROR_CODE_MISPLACED_CHARACTER
        from com.sun.star.ucb.IOErrorCode import NAME_TOO_LONG as I_O_ERROR_CODE_NAME_TOO_LONG
        from com.sun.star.ucb.IOErrorCode import NOT_EXISTING as I_O_ERROR_CODE_NOT_EXISTING
        from com.sun.star.ucb.IOErrorCode import NOT_EXISTING_PATH as I_O_ERROR_CODE_NOT_EXISTING_PATH
        from com.sun.star.ucb.IOErrorCode import NOT_SUPPORTED as I_O_ERROR_CODE_NOT_SUPPORTED
        from com.sun.star.ucb.IOErrorCode import NO_DIRECTORY as I_O_ERROR_CODE_NO_DIRECTORY
        from com.sun.star.ucb.IOErrorCode import NO_FILE as I_O_ERROR_CODE_NO_FILE
        from com.sun.star.ucb.IOErrorCode import OUT_OF_DISK_SPACE as I_O_ERROR_CODE_OUT_OF_DISK_SPACE
        from com.sun.star.ucb.IOErrorCode import OUT_OF_FILE_HANDLES as I_O_ERROR_CODE_OUT_OF_FILE_HANDLES
        from com.sun.star.ucb.IOErrorCode import OUT_OF_MEMORY as I_O_ERROR_CODE_OUT_OF_MEMORY
        from com.sun.star.ucb.IOErrorCode import PENDING as I_O_ERROR_CODE_PENDING
        from com.sun.star.ucb.IOErrorCode import RECURSIVE as I_O_ERROR_CODE_RECURSIVE
        from com.sun.star.ucb.IOErrorCode import UNKNOWN as I_O_ERROR_CODE_UNKNOWN
        from com.sun.star.ucb.IOErrorCode import WRITE_PROTECTED as I_O_ERROR_CODE_WRITE_PROTECTED
        from com.sun.star.ucb.IOErrorCode import WRONG_FORMAT as I_O_ERROR_CODE_WRONG_FORMAT
        from com.sun.star.ucb.IOErrorCode import WRONG_VERSION as I_O_ERROR_CODE_WRONG_VERSION

        class IOErrorCode(uno.Enum):
            """
            Enum Class


            See Also:
                `API IOErrorCode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.ucb.IOErrorCode', value)

            __ooo_ns__: str = 'com.sun.star.ucb'
            __ooo_full_ns__: str = 'com.sun.star.ucb.IOErrorCode'
            __ooo_type_name__: str = 'enum'

            ABORT = I_O_ERROR_CODE_ABORT
            """
            An operation was aborted.
            """
            ACCESS_DENIED = I_O_ERROR_CODE_ACCESS_DENIED
            """
            An object cannot be accessed due to insufficient user rights.
            """
            ALREADY_EXISTING = I_O_ERROR_CODE_ALREADY_EXISTING
            """
            An object already exists.
            """
            BAD_CRC = I_O_ERROR_CODE_BAD_CRC
            """
            A bad checksum.
            """
            CANT_CREATE = I_O_ERROR_CODE_CANT_CREATE
            """
            An object could not be created.
            """
            CANT_READ = I_O_ERROR_CODE_CANT_READ
            """
            Data could not be read from a file.
            """
            CANT_SEEK = I_O_ERROR_CODE_CANT_SEEK
            """
            A seek operation could not be run.
            """
            CANT_TELL = I_O_ERROR_CODE_CANT_TELL
            """
            A tell operation could not be run.
            """
            CANT_WRITE = I_O_ERROR_CODE_CANT_WRITE
            """
            Data could not be written to a file.
            """
            CURRENT_DIRECTORY = I_O_ERROR_CODE_CURRENT_DIRECTORY
            """
            A function is not possible because the path contains the current directory.
            """
            DEVICE_NOT_READY = I_O_ERROR_CODE_DEVICE_NOT_READY
            """
            A device (drive) not ready.
            """
            DIFFERENT_DEVICES = I_O_ERROR_CODE_DIFFERENT_DEVICES
            """
            A function is not possible because the devices (drives) are not identical.
            """
            GENERAL = I_O_ERROR_CODE_GENERAL
            """
            A general input/output error.
            """
            INVALID_ACCESS = I_O_ERROR_CODE_INVALID_ACCESS
            """
            An invalid attempt was made to access an object.
            """
            INVALID_CHARACTER = I_O_ERROR_CODE_INVALID_CHARACTER
            """
            A file name contains invalid characters.
            """
            INVALID_DEVICE = I_O_ERROR_CODE_INVALID_DEVICE
            """
            A specified device is invalid.
            """
            INVALID_LENGTH = I_O_ERROR_CODE_INVALID_LENGTH
            """
            Invalid data length.
            """
            INVALID_PARAMETER = I_O_ERROR_CODE_INVALID_PARAMETER
            """
            An operation was started with an invalid parameter.
            """
            IS_WILDCARD = I_O_ERROR_CODE_IS_WILDCARD
            """
            An operation cannot be run on file names containing wildcards.
            """
            LOCKING_VIOLATION = I_O_ERROR_CODE_LOCKING_VIOLATION
            """
            A locking problem.
            """
            MISPLACED_CHARACTER = I_O_ERROR_CODE_MISPLACED_CHARACTER
            """
            An invalid file name.
            """
            NAME_TOO_LONG = I_O_ERROR_CODE_NAME_TOO_LONG
            """
            A file name is too long.
            """
            NOT_EXISTING = I_O_ERROR_CODE_NOT_EXISTING
            """
            A nonexistent object.
            """
            NOT_EXISTING_PATH = I_O_ERROR_CODE_NOT_EXISTING_PATH
            """
            The path to a file does not exist.
            """
            NOT_SUPPORTED = I_O_ERROR_CODE_NOT_SUPPORTED
            """
            An action is not supported.
            """
            NO_DIRECTORY = I_O_ERROR_CODE_NO_DIRECTORY
            """
            An object is not a directory.
            """
            NO_FILE = I_O_ERROR_CODE_NO_FILE
            """
            An object is not a file.
            """
            OUT_OF_DISK_SPACE = I_O_ERROR_CODE_OUT_OF_DISK_SPACE
            """
            No more space on a device.
            """
            OUT_OF_FILE_HANDLES = I_O_ERROR_CODE_OUT_OF_FILE_HANDLES
            """
            No more file handles available.
            """
            OUT_OF_MEMORY = I_O_ERROR_CODE_OUT_OF_MEMORY
            """
            An operation could not be run due to insufficient memory.
            """
            PENDING = I_O_ERROR_CODE_PENDING
            """
            An operation is still pending.
            """
            RECURSIVE = I_O_ERROR_CODE_RECURSIVE
            """
            An object cannot be copied into itself.
            """
            UNKNOWN = I_O_ERROR_CODE_UNKNOWN
            """
            Unknown.

            An unknown I/O error has occurred.
            """
            WRITE_PROTECTED = I_O_ERROR_CODE_WRITE_PROTECTED
            """
            A function is not possible because the object is write protected.
            """
            WRONG_FORMAT = I_O_ERROR_CODE_WRONG_FORMAT
            """
            An incorrect file format.
            """
            WRONG_VERSION = I_O_ERROR_CODE_WRONG_VERSION
            """
            An incorrect file version.
            """
    else:
        # keep document generators happy
        from ...lo.ucb.io_error_code import IOErrorCode as IOErrorCode


__all__ = ['IOErrorCode']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_window import XWindow as XWindow_713b0924
    from .x_window_peer import XWindowPeer as XWindowPeer_99760ab0

class XContainerWindowProvider(XInterface_8f010a43):
    """
    provides container windows implementing the com.sun.star.awt.XWindow interface.

    See Also:
        `API XContainerWindowProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XContainerWindowProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XContainerWindowProvider'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XContainerWindowProvider'

    @abstractmethod
    def createContainerWindow(self, URL: str, WindowType: str, xParent: XWindowPeer_99760ab0, xHandler: XInterface_8f010a43) -> XWindow_713b0924:
        """
        creates a window for the given URL
        
        xHandler can handle events in two different ways:
        
        If XContainerWindowEventHandler is supported XContainerWindowEventHandler.callHandlerMethod() is always called first to handle the event. Only if the event cannot be handled by XContainerWindowEventHandler (callHandlerMethod() then has to return false) or if XContainerWindowEventHandler is not supported at all the Introspection based access will be used.
        
        The Introspection based access tries to call a method named according to the HandlerMethodName specified by a vnd.sun.star.UNO:HandlerMethodName URL. First a method
        
        void HandlerMethodName( [in] com.sun.star.awt.XWindow xWindow, [in] any aEvent )
        
        will be searched. The signature is similar to XContainerWindowEventHandler. callHandlerMethod except for MethodName itself that isn't needed here. For more information about these parameters, see com.sun.star.awt.XContainerWindowEventHandler.
        
        If this method is found, it will be called, otherwise a method
        
        void HandlerMethodName( void )
        
        will be searched and called.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XContainerWindowProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_window import XWindow as XWindow_713b0924
    from ..datatransfer.clipboard.x_clipboard import XClipboard as XClipboard_a18a11cd
    from ..datatransfer.dnd.x_drag_gesture_recognizer import XDragGestureRecognizer as XDragGestureRecognizer_10741438
    from ..datatransfer.dnd.x_drag_source import XDragSource as XDragSource_49900fb2
    from ..datatransfer.dnd.x_drop_target import XDropTarget as XDropTarget_49e50fbf

class XDataTransferProviderAccess(XInterface_8f010a43):
    """
    This interface extends the XToolkit interface with clipboard and drag-and-drop support.

    See Also:
        `API XDataTransferProviderAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDataTransferProviderAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XDataTransferProviderAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XDataTransferProviderAccess'

    @abstractmethod
    def getClipboard(self, clipboardName: str) -> XClipboard_a18a11cd:
        """
        returns the specified clipboard.
        """
        ...
    @abstractmethod
    def getDragGestureRecognizer(self, window: XWindow_713b0924) -> XDragGestureRecognizer_10741438:
        """
        returns the drag gesture recognizer of the specified window.
        """
        ...
    @abstractmethod
    def getDragSource(self, window: XWindow_713b0924) -> XDragSource_49900fb2:
        """
        returns the drag source of the specified window.
        """
        ...
    @abstractmethod
    def getDropTarget(self, window: XWindow_713b0924) -> XDropTarget_49e50fbf:
        """
        returns the drop target of the specified window.
        """
        ...

__all__ = ['XDataTransferProviderAccess']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.form
# Libre Office Version: 7.4
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from enum import Enum
if TYPE_CHECKING:
    from com.sun.star.form.NavigationBarMode import NavigationBarModeProto

class NavigationBarMode(Enum):
    """
    Enum Class


    See Also:
        `API NavigationBarMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form.html#ad79e40635743aa91020c7ddf34c3af31>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.NavigationBarMode'
    __ooo_type_name__: str = 'enum'

    @property
    def typeName(self) -> str:
        return 'com.sun.star.form.NavigationBarMode'

    CURRENT = cast("NavigationBarModeProto", 'CURRENT')
    """
    a navigation bar is provided and navigation will be performed on the current/active form.
    
    pressing the TAB key from the last control moves the focus to the first control in the tab order of the same record.
    
    This is the default and most often encountered mode.
    """
    NONE = cast("NavigationBarModeProto", 'NONE')
    """
    no navigation bar is provided and navigation on the current form is only possible with the keyboard (TAB/SHIFT TAB).
    
    Note that when this mode is set, a simultaneous TabulatorCycle value of TabulatorCycle.CURRENT means that you cannot travel between records anymore.
    """
    PARENT = cast("NavigationBarModeProto", 'PARENT')
    """
    a navigation bar is provided and navigation will be performed on the parent of the current/active form.
    
    This option is usually used for forms containing a grid control only. In such a form, the control has its own navigation elements, so there is no need to use the navigation bar for the form, but rather for its parent.
    """

__all__ = ['NavigationBarMode']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class DictionaryListEventFlags(metaclass=UnoConstMeta, type_name="com.sun.star.linguistic2.DictionaryListEventFlags", name_space="com.sun.star.linguistic2"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.linguistic2.DictionaryListEventFlags``"""
        pass

    class DictionaryListEventFlagsEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.linguistic2.DictionaryListEventFlags", name_space="com.sun.star.linguistic2"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.linguistic2.DictionaryListEventFlags`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.linguistic2 import DictionaryListEventFlags as DictionaryListEventFlags
    else:
        # keep document generators happy
        from ...lo.linguistic2.dictionary_list_event_flags import DictionaryListEventFlags as DictionaryListEventFlags

    class DictionaryListEventFlagsEnum(IntFlag):
        """
        Enum of Const Class DictionaryListEventFlags

        constants representing a single dictionary-list event.
        
        These flags define the possible types for a dictionary-list event.
        """
        ADD_POS_ENTRY = DictionaryListEventFlags.ADD_POS_ENTRY
        """
        A positive entry was added to a dictionary from the dictionary list.
        """
        DEL_POS_ENTRY = DictionaryListEventFlags.DEL_POS_ENTRY
        """
        A positive entry was deleted from a dictionary of the dictionary-list or a dictionary with positive entries was cleared.
        """
        ADD_NEG_ENTRY = DictionaryListEventFlags.ADD_NEG_ENTRY
        """
        A negative entry was added to a dictionary from the dictionary-list.
        """
        DEL_NEG_ENTRY = DictionaryListEventFlags.DEL_NEG_ENTRY
        """
        A negative entry was deleted from a dictionary of the dictionary-list or a dictionary with negative entries was cleared.
        """
        ACTIVATE_POS_DIC = DictionaryListEventFlags.ACTIVATE_POS_DIC
        """
        A dictionary with positive entries was activated or has changed its language.
        """
        DEACTIVATE_POS_DIC = DictionaryListEventFlags.DEACTIVATE_POS_DIC
        """
        A dictionary with positive entries was deactivated or has changed its language.
        """
        ACTIVATE_NEG_DIC = DictionaryListEventFlags.ACTIVATE_NEG_DIC
        """
        A dictionary with negative entries was activated or has changed its language.
        """
        DEACTIVATE_NEG_DIC = DictionaryListEventFlags.DEACTIVATE_NEG_DIC
        """
        A dictionary with negative entries was deactivated or has changed its language.
        """

__all__ = ['DictionaryListEventFlags', 'DictionaryListEventFlagsEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet


class ConditionFormatOperator(object):
    """
    Const Class


    See Also:
        `API ConditionFormatOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet_1_1ConditionFormatOperator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.ConditionFormatOperator'
    __ooo_type_name__: str = 'const'

    EQUAL = 0
    LESS = 1
    GREATER = 2
    LESS_EQUAL = 3
    GREATER_EQUAL = 4
    NOT_EQUAL = 5
    BETWEEN = 6
    NOT_BETWEEN = 7
    DUPLICATE = 8
    UNIQUE = 9
    TOP_N_ELEMENTS = 10
    BOTTOM_N_ELEMENTS = 11
    TOP_N_PERCENT = 12
    BOTTOM_N_PERCENT = 13
    ABOVE_AVERAGE = 14
    BELOW_AVERAGE = 15
    ABOVE_EQUAL_AVERAGE = 16
    BELOW_EQUAL_AVERAGE = 17
    ERROR = 18
    NO_ERROR = 19
    BEGINS_WITH = 20
    ENDS_WITH = 21
    CONTAINS = 22
    NOT_CONTAINS = 23
    EXPRESSION = 24

__all__ = ['ConditionFormatOperator']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class TextureKind(metaclass=UnoEnumMeta, type_name="com.sun.star.drawing.TextureKind", name_space="com.sun.star.drawing"):
        """Dynamically created class that represents ``com.sun.star.drawing.TextureKind`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.drawing.TextureKind import COLOR as TEXTURE_KIND_COLOR
        from com.sun.star.drawing.TextureKind import LUMINANCE as TEXTURE_KIND_LUMINANCE

        class TextureKind(uno.Enum):
            """
            Enum Class


            See Also:
                `API TextureKind <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a36a384629c2a5cfb1a9d019d30923c2b>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.drawing.TextureKind', value)

            __ooo_ns__: str = 'com.sun.star.drawing'
            __ooo_full_ns__: str = 'com.sun.star.drawing.TextureKind'
            __ooo_type_name__: str = 'enum'

            COLOR = TEXTURE_KIND_COLOR
            """
            With this mode the lighting is ignored and only the texture color information is used.

            With this mode, the lighting is ignored and only the texture color information is used.
            """
            LUMINANCE = TEXTURE_KIND_LUMINANCE
            """
            With TextureKind LUMINANCE, the texture and the lighting information is mixed to produce the image, so a lit, textured object is achieved.
            """
    else:
        # keep document generators happy
        from ...lo.drawing.texture_kind import TextureKind as TextureKind


__all__ = ['TextureKind']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Singleton Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.util
# Libre Office Version: 7.4
from .x_office_installation_directories import XOfficeInstallationDirectories as XOfficeInstallationDirectories_c38f12d9


class theOfficeInstallationDirectories(XOfficeInstallationDirectories_c38f12d9):
    """
    Singleton Class

    encapsulates access to the current office installation directory and office user data directory, provides functionality to create URLs containing relocatable (not absolute) references to the current office installation directory and user data directory and vice versa.
    
    This functionality is useful when data containing references to the current office installation directory or user data directory must be made persistent and re-read later. In many cases, storing the reference directly would destroy the relocatability of an office installation and the possibility to share one office user data directory among parallel office installations.

    See Also:
        `API theOfficeInstallationDirectories <https://api.libreoffice.org/docs/idl/ref/singletoncom_1_1sun_1_1star_1_1util_1_1theOfficeInstallationDirectories.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.theOfficeInstallationDirectories'
    __ooo_type_name__: str = 'singleton'
    _instance = None

    def __new__(cls, *args, **kwargs):
        # single instance only allowed
        if cls._instance is None:
            cls._instance = super().__new__(cls, *args, **kwargs)
        return cls._instance


__all__ = ['theOfficeInstallationDirectories']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_action_listener import XActionListener as XActionListener_c7560c50
    from .x_item_listener import XItemListener as XItemListener_af710b81

class XComboBox(XInterface_8f010a43):
    """
    gives access to the items of a combo box and makes it possible to register item and action event listeners.

    See Also:
        `API XComboBox <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XComboBox.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XComboBox'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XComboBox'

    @abstractmethod
    def addActionListener(self, l: XActionListener_c7560c50) -> None:
        """
        registers a listener for action events.
        """
        ...
    @abstractmethod
    def addItem(self, aItem: str, nPos: int) -> None:
        """
        adds an item at the specified position.
        """
        ...
    @abstractmethod
    def addItemListener(self, l: XItemListener_af710b81) -> None:
        """
        registers a listener for item events.
        """
        ...
    @abstractmethod
    def addItems(self, aItems: typing.Tuple[str, ...], nPos: int) -> None:
        """
        adds multiple items at the specified position.
        """
        ...
    @abstractmethod
    def getDropDownLineCount(self) -> int:
        """
        returns the number of visible lines in the drop down mode.
        """
        ...
    @abstractmethod
    def getItem(self, nPos: int) -> str:
        """
        returns the item at the specified position.
        """
        ...
    @abstractmethod
    def getItemCount(self) -> int:
        """
        returns the number of items in the combo box.
        """
        ...
    @abstractmethod
    def getItems(self) -> typing.Tuple[str, ...]:
        """
        returns all items of the combo box.
        """
        ...
    @abstractmethod
    def removeActionListener(self, l: XActionListener_c7560c50) -> None:
        """
        unregisters a listener for action events.
        """
        ...
    @abstractmethod
    def removeItemListener(self, l: XItemListener_af710b81) -> None:
        """
        unregisters a listener for item events.
        """
        ...
    @abstractmethod
    def removeItems(self, nPos: int, nCount: int) -> None:
        """
        removes a number of items at the specified position.
        """
        ...
    @abstractmethod
    def setDropDownLineCount(self, nLines: int) -> None:
        """
        sets the number of visible lines for drop down mode.
        """
        ...

__all__ = ['XComboBox']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from com.sun.star.chart.ChartErrorCategory import ChartErrorCategoryProto
    from com.sun.star.chart.ChartErrorIndicatorType import ChartErrorIndicatorTypeProto
    from com.sun.star.chart.ChartRegressionCurveType import ChartRegressionCurveTypeProto

class ChartStatistics(XPropertySet_bc180bfa):
    """
    Service Class

    offers statistical properties for the data in the chart.
    
    It is available for a single data row and for the whole diagram.

    See Also:
        `API ChartStatistics <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartStatistics.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartStatistics'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ConstantErrorHigh(self) -> float:
        """
        specifies the upper limit of the error range of a data row.
        
        this setting is effective if the ChartStatistics.ErrorCategory is set to ChartErrorCategory.CONSTANT_VALUE.
        """
        ...

    @abstractproperty
    def ConstantErrorLow(self) -> float:
        """
        specifies the lower limit of the error range of a data row.
        
        this setting is effective if the ChartStatistics.ErrorCategory is set to ChartErrorCategory.CONSTANT_VALUE.
        """
        ...

    @abstractproperty
    def ErrorBarRangeNegative(self) -> str:
        """
        contains a cell range string for negative error bars.
        
        This property is used when the ErrorBarCategory is set to ErrorBarCategory.FROM_DATA.
        """
        ...

    @abstractproperty
    def ErrorBarRangePositive(self) -> str:
        """
        contains a cell range string for positive error bars.
        
        This property is used when the ErrorBarCategory is set to ErrorBarCategory.FROM_DATA.
        """
        ...

    @abstractproperty
    def ErrorBarStyle(self) -> int:
        """
        determines the style of the error bars.
        
        Use this instead of ErrorCategory
        """
        ...

    @abstractproperty
    def ErrorCategory(self) -> ChartErrorCategoryProto:
        """
        determines the type of error to indicate.
        """
        ...

    @abstractproperty
    def ErrorIndicator(self) -> ChartErrorIndicatorTypeProto:
        """
        determines how the error is indicated.
        
        You can enable indicators pointing up, down or both.
        """
        ...

    @abstractproperty
    def ErrorMargin(self) -> float:
        """
        specifies the percentage for the margin of errors.
        
        The length of the error indicators is calculated by taking the percentage given of the largest data point value.
        
        this setting is effective if the ChartStatistics.ErrorCategory is set to ChartErrorCategory.ERROR_MARGIN.
        """
        ...

    @abstractproperty
    def MeanValue(self) -> bool:
        """
        determines if the mean value for a data row is displayed as a line.
        """
        ...

    @abstractproperty
    def PercentageError(self) -> float:
        """
        specifies the percentage that is used to display error bars.
        
        The length of the error indicators is calculated for each data point by taking the given percentage of its value.
        
        this setting is effective if the ChartStatistics.ErrorCategory is set to ChartErrorCategory.PERCENT.
        """
        ...

    @abstractproperty
    def RegressionCurves(self) -> ChartRegressionCurveTypeProto:
        """
        determines a type of regression for the data row values.
        """
        ...


__all__ = ['ChartStatistics']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from .shape import Shape as Shape_85cc09e5
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class AppletShape(Shape_85cc09e5):
    """
    Service Class

    This Shape encapsulates an applet.
    
    An applet is a small Java-based program that is executed and rendered embedded in a document.

    See Also:
        `API AppletShape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1AppletShape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.AppletShape'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AppletCommands(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        This sequence contains parameters that are passed to the applet when it is initialized.
        """
        ...

    @abstractproperty
    def AppletCode(self) -> str:
        """
        This property specifies one of the following: The name of the class file that contains the compiled applet subclass.
        
        The path to the class, including the class file itself.
        """
        ...

    @abstractproperty
    def AppletCodeBase(self) -> str:
        """
        This property specifies the base URI for the applet.
        
        If this property is empty, then it defaults the same base URI as for the current document.
        """
        ...

    @abstractproperty
    def AppletIsScript(self) -> bool:
        """
        This property specifies whether or not the applet can be scripted.
        """
        ...

    @abstractproperty
    def AppletName(self) -> str:
        """
        this is an optional name for the applet.
        """
        ...


__all__ = ['AppletShape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
from abc import abstractmethod
from .x_transliteration import XTransliteration as XTransliteration_daf70ce3

class XExtendedTransliteration(XTransliteration_daf70ce3):
    """
    This interface provides character conversions like case folding or Hiragana to Katakana.
    
    It is derived from com.sun.star.i18n.XTransliteration and provides additional functionality for character to character and string to string without offset parameter transliteration. These should be used for performance reason if their full-blown counterparts aren't needed.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XExtendedTransliteration <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XExtendedTransliteration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XExtendedTransliteration'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XExtendedTransliteration'

    @abstractmethod
    def transliterateChar2Char(self, cChar: str) -> str:
        """
        Transliterate a character to a character.
        
        If the output contains multiple characters, for example when transliterating German sharp \"s\" (the one that looks like a Greek Beta) to upper case \"SS\", MultipleCharsOutputException will be thrown, the caller must catch the exception and then call XTransliteration.transliterateChar2String() to obtain the correct result.

        Raises:
            MultipleCharsOutputException: ``MultipleCharsOutputException``
        """
        ...
    @abstractmethod
    def transliterateChar2String(self, cChar: str) -> str:
        """
        Transliterate a character to a string.
        """
        ...
    @abstractmethod
    def transliterateString2String(self, aStr: str, nStartPos: int, nCount: int) -> str:
        """
        Transliterate a substring.
        
        The functionality is the same as com.sun.star.i18n.XTransliteration.transliterate() but omits the offset parameter to improve performance.
        """
        ...

__all__ = ['XExtendedTransliteration']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.4
from __future__ import annotations
import uno
from typing import Any, TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoEnumMeta
    class ChartRegressionCurveType(metaclass=UnoEnumMeta, type_name="com.sun.star.chart.ChartRegressionCurveType", name_space="com.sun.star.chart"):
        """Dynamically created class that represents ``com.sun.star.chart.ChartRegressionCurveType`` Enum. Class loosely mimics Enum"""
        pass
else:
    if TYPE_CHECKING:
        from com.sun.star.chart.ChartRegressionCurveType import EXPONENTIAL as CHART_REGRESSION_CURVE_TYPE_EXPONENTIAL
        from com.sun.star.chart.ChartRegressionCurveType import LINEAR as CHART_REGRESSION_CURVE_TYPE_LINEAR
        from com.sun.star.chart.ChartRegressionCurveType import LOGARITHM as CHART_REGRESSION_CURVE_TYPE_LOGARITHM
        from com.sun.star.chart.ChartRegressionCurveType import NONE as CHART_REGRESSION_CURVE_TYPE_NONE
        from com.sun.star.chart.ChartRegressionCurveType import POLYNOMIAL as CHART_REGRESSION_CURVE_TYPE_POLYNOMIAL
        from com.sun.star.chart.ChartRegressionCurveType import POWER as CHART_REGRESSION_CURVE_TYPE_POWER

        class ChartRegressionCurveType(uno.Enum):
            """
            Enum Class


            See Also:
                `API ChartRegressionCurveType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302b>`_
            """

            def __init__(self, value: Any) -> None:
                super().__init__('com.sun.star.chart.ChartRegressionCurveType', value)

            __ooo_ns__: str = 'com.sun.star.chart'
            __ooo_full_ns__: str = 'com.sun.star.chart.ChartRegressionCurveType'
            __ooo_type_name__: str = 'enum'

            EXPONENTIAL = CHART_REGRESSION_CURVE_TYPE_EXPONENTIAL
            """
            displays an exponential regression curve.
            """
            LINEAR = CHART_REGRESSION_CURVE_TYPE_LINEAR
            """
            displays a linear regression curve.
            """
            LOGARITHM = CHART_REGRESSION_CURVE_TYPE_LOGARITHM
            """
            displays a linear logarithmic regression curve.
            """
            NONE = CHART_REGRESSION_CURVE_TYPE_NONE
            """
            error indicators are not displayed.

            displays no regression curve.

            no chart legend is displayed.

            displays no error indicators.
            """
            POLYNOMIAL = CHART_REGRESSION_CURVE_TYPE_POLYNOMIAL
            """
            displays a polynomial regression curve.
            """
            POWER = CHART_REGRESSION_CURVE_TYPE_POWER
            """
            displays a regression curve using a power function.

            displays a moving average regression curve.
            """
    else:
        # keep document generators happy
        from ...lo.chart.chart_regression_curve_type import ChartRegressionCurveType as ChartRegressionCurveType


__all__ = ['ChartRegressionCurveType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.i18n
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class LocaleDataItem(object):
    """
    Struct Class

    Locale specific data, for example, separators, quotation marks.

    See Also:
        `API LocaleDataItem <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1i18n_1_1LocaleDataItem.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.LocaleDataItem'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.i18n.LocaleDataItem'
    """Literal Constant ``com.sun.star.i18n.LocaleDataItem``"""

    def __init__(self, unoID: typing.Optional[str] = '', dateSeparator: typing.Optional[str] = '', thousandSeparator: typing.Optional[str] = '', decimalSeparator: typing.Optional[str] = '', timeSeparator: typing.Optional[str] = '', time100SecSeparator: typing.Optional[str] = '', listSeparator: typing.Optional[str] = '', quotationStart: typing.Optional[str] = '', quotationEnd: typing.Optional[str] = '', doubleQuotationStart: typing.Optional[str] = '', doubleQuotationEnd: typing.Optional[str] = '', timeAM: typing.Optional[str] = '', timePM: typing.Optional[str] = '', measurementSystem: typing.Optional[str] = '', LongDateDayOfWeekSeparator: typing.Optional[str] = '', LongDateDaySeparator: typing.Optional[str] = '', LongDateMonthSeparator: typing.Optional[str] = '', LongDateYearSeparator: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            unoID (str, optional): unoID value.
            dateSeparator (str, optional): dateSeparator value.
            thousandSeparator (str, optional): thousandSeparator value.
            decimalSeparator (str, optional): decimalSeparator value.
            timeSeparator (str, optional): timeSeparator value.
            time100SecSeparator (str, optional): time100SecSeparator value.
            listSeparator (str, optional): listSeparator value.
            quotationStart (str, optional): quotationStart value.
            quotationEnd (str, optional): quotationEnd value.
            doubleQuotationStart (str, optional): doubleQuotationStart value.
            doubleQuotationEnd (str, optional): doubleQuotationEnd value.
            timeAM (str, optional): timeAM value.
            timePM (str, optional): timePM value.
            measurementSystem (str, optional): measurementSystem value.
            LongDateDayOfWeekSeparator (str, optional): LongDateDayOfWeekSeparator value.
            LongDateDaySeparator (str, optional): LongDateDaySeparator value.
            LongDateMonthSeparator (str, optional): LongDateMonthSeparator value.
            LongDateYearSeparator (str, optional): LongDateYearSeparator value.
        """
        super().__init__()

        if isinstance(unoID, LocaleDataItem):
            oth: LocaleDataItem = unoID
            self.unoID = oth.unoID
            self.dateSeparator = oth.dateSeparator
            self.thousandSeparator = oth.thousandSeparator
            self.decimalSeparator = oth.decimalSeparator
            self.timeSeparator = oth.timeSeparator
            self.time100SecSeparator = oth.time100SecSeparator
            self.listSeparator = oth.listSeparator
            self.quotationStart = oth.quotationStart
            self.quotationEnd = oth.quotationEnd
            self.doubleQuotationStart = oth.doubleQuotationStart
            self.doubleQuotationEnd = oth.doubleQuotationEnd
            self.timeAM = oth.timeAM
            self.timePM = oth.timePM
            self.measurementSystem = oth.measurementSystem
            self.LongDateDayOfWeekSeparator = oth.LongDateDayOfWeekSeparator
            self.LongDateDaySeparator = oth.LongDateDaySeparator
            self.LongDateMonthSeparator = oth.LongDateMonthSeparator
            self.LongDateYearSeparator = oth.LongDateYearSeparator
            return

        kargs = {
            "unoID": unoID,
            "dateSeparator": dateSeparator,
            "thousandSeparator": thousandSeparator,
            "decimalSeparator": decimalSeparator,
            "timeSeparator": timeSeparator,
            "time100SecSeparator": time100SecSeparator,
            "listSeparator": listSeparator,
            "quotationStart": quotationStart,
            "quotationEnd": quotationEnd,
            "doubleQuotationStart": doubleQuotationStart,
            "doubleQuotationEnd": doubleQuotationEnd,
            "timeAM": timeAM,
            "timePM": timePM,
            "measurementSystem": measurementSystem,
            "LongDateDayOfWeekSeparator": LongDateDayOfWeekSeparator,
            "LongDateDaySeparator": LongDateDaySeparator,
            "LongDateMonthSeparator": LongDateMonthSeparator,
            "LongDateYearSeparator": LongDateYearSeparator,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._uno_id = kwargs["unoID"]
        self._date_separator = kwargs["dateSeparator"]
        self._thousand_separator = kwargs["thousandSeparator"]
        self._decimal_separator = kwargs["decimalSeparator"]
        self._time_separator = kwargs["timeSeparator"]
        self._time100_sec_separator = kwargs["time100SecSeparator"]
        self._list_separator = kwargs["listSeparator"]
        self._quotation_start = kwargs["quotationStart"]
        self._quotation_end = kwargs["quotationEnd"]
        self._double_quotation_start = kwargs["doubleQuotationStart"]
        self._double_quotation_end = kwargs["doubleQuotationEnd"]
        self._time_am = kwargs["timeAM"]
        self._time_pm = kwargs["timePM"]
        self._measurement_system = kwargs["measurementSystem"]
        self._long_date_day_of_week_separator = kwargs["LongDateDayOfWeekSeparator"]
        self._long_date_day_separator = kwargs["LongDateDaySeparator"]
        self._long_date_month_separator = kwargs["LongDateMonthSeparator"]
        self._long_date_year_separator = kwargs["LongDateYearSeparator"]


    @property
    def unoID(self) -> str:
        """
        internal ID string, not unique, not meaningful to the outer world
        """
        return self._uno_id

    @unoID.setter
    def unoID(self, value: str) -> None:
        self._uno_id = value

    @property
    def dateSeparator(self) -> str:
        """
        date separator, for example, \"/\" or \".\" or \"-\"
        """
        return self._date_separator

    @dateSeparator.setter
    def dateSeparator(self, value: str) -> None:
        self._date_separator = value

    @property
    def thousandSeparator(self) -> str:
        """
        group and thousand separator, for example, \",\" or \".\"
        """
        return self._thousand_separator

    @thousandSeparator.setter
    def thousandSeparator(self, value: str) -> None:
        self._thousand_separator = value

    @property
    def decimalSeparator(self) -> str:
        """
        decimal separator, for example, \".\" or \",\"
        """
        return self._decimal_separator

    @decimalSeparator.setter
    def decimalSeparator(self, value: str) -> None:
        self._decimal_separator = value

    @property
    def timeSeparator(self) -> str:
        """
        time separator, for example, \":\"
        """
        return self._time_separator

    @timeSeparator.setter
    def timeSeparator(self, value: str) -> None:
        self._time_separator = value

    @property
    def time100SecSeparator(self) -> str:
        """
        time 100th seconds separator, for example, \",\"
        """
        return self._time100_sec_separator

    @time100SecSeparator.setter
    def time100SecSeparator(self, value: str) -> None:
        self._time100_sec_separator = value

    @property
    def listSeparator(self) -> str:
        """
        list separator, for example, \";\"
        """
        return self._list_separator

    @listSeparator.setter
    def listSeparator(self, value: str) -> None:
        self._list_separator = value

    @property
    def quotationStart(self) -> str:
        """
        single quotation mark start
        """
        return self._quotation_start

    @quotationStart.setter
    def quotationStart(self, value: str) -> None:
        self._quotation_start = value

    @property
    def quotationEnd(self) -> str:
        """
        single quotation mark end
        """
        return self._quotation_end

    @quotationEnd.setter
    def quotationEnd(self, value: str) -> None:
        self._quotation_end = value

    @property
    def doubleQuotationStart(self) -> str:
        """
        double quotation mark start
        """
        return self._double_quotation_start

    @doubleQuotationStart.setter
    def doubleQuotationStart(self, value: str) -> None:
        self._double_quotation_start = value

    @property
    def doubleQuotationEnd(self) -> str:
        """
        double quotation mark end
        """
        return self._double_quotation_end

    @doubleQuotationEnd.setter
    def doubleQuotationEnd(self, value: str) -> None:
        self._double_quotation_end = value

    @property
    def timeAM(self) -> str:
        """
        time AM symbol, for example, \"AM\" or \"am\"
        """
        return self._time_am

    @timeAM.setter
    def timeAM(self, value: str) -> None:
        self._time_am = value

    @property
    def timePM(self) -> str:
        """
        time PM symbol, for example, \"PM\" or \"pm\"
        """
        return self._time_pm

    @timePM.setter
    def timePM(self, value: str) -> None:
        self._time_pm = value

    @property
    def measurementSystem(self) -> str:
        """
        measurement system, \"metric\" or \"us\"
        """
        return self._measurement_system

    @measurementSystem.setter
    def measurementSystem(self, value: str) -> None:
        self._measurement_system = value

    @property
    def LongDateDayOfWeekSeparator(self) -> str:
        """
        long date day of week separator, for example, \", \"
        """
        return self._long_date_day_of_week_separator

    @LongDateDayOfWeekSeparator.setter
    def LongDateDayOfWeekSeparator(self, value: str) -> None:
        self._long_date_day_of_week_separator = value

    @property
    def LongDateDaySeparator(self) -> str:
        """
        long date day separator, for example, \", \"
        """
        return self._long_date_day_separator

    @LongDateDaySeparator.setter
    def LongDateDaySeparator(self, value: str) -> None:
        self._long_date_day_separator = value

    @property
    def LongDateMonthSeparator(self) -> str:
        """
        long date month separator, for example, \" \"
        """
        return self._long_date_month_separator

    @LongDateMonthSeparator.setter
    def LongDateMonthSeparator(self, value: str) -> None:
        self._long_date_month_separator = value

    @property
    def LongDateYearSeparator(self) -> str:
        """
        long date year separator, for example, \" \"
        """
        return self._long_date_year_separator

    @LongDateYearSeparator.setter
    def LongDateYearSeparator(self, value: str) -> None:
        self._long_date_year_separator = value


__all__ = ['LocaleDataItem']
